@@ -1,2 +1,5 @@
 from .core import run, rank_scores
 from .dataset import Experiment, GeneExpressionDataset
+
+__version__ = '0.0.17'
+__author__ = 'Antoine Passemiers'
